@@ -1,18 +1,25 @@
 from __future__ import annotations
 
 import os
+import pathlib
 from typing import Dict, Set, Union
 
 import fsspec
 from fsspec import AbstractFileSystem
 
 from .cli_utils import echo_subinfo
+from .errors import DataPipelinesError
 
 
 class LocalRemoteSync:
+    """Synchronizes local directory with a cloud storage's one"""
+
     local_fs: AbstractFileSystem
+    """FS representing local directory"""
     local_path_str: str
+    """Path to local directory"""
     remote_path_str: str
+    """Path/URI of the cloud storage directory"""
     _local_directory_suffixes: Set[str]
 
     def __init__(
@@ -20,7 +27,12 @@ class LocalRemoteSync:
         local_path: Union[str, os.PathLike[str]],
         remote_path: str,
         remote_kwargs: Dict[str, str],
-    ):
+    ) -> None:
+        if not pathlib.Path(local_path).exists():
+            raise DataPipelinesError(
+                f"{local_path} does not exists. Run 'dp compile' before."
+            )
+
         self.local_path_str = str(local_path).rstrip("/")
         self.local_fs = fsspec.filesystem("file")
         self.remote_fs, self.remote_path_str = fsspec.core.url_to_fs(
@@ -29,6 +41,14 @@ class LocalRemoteSync:
         self._local_directory_suffixes = set()
 
     def sync(self, delete: bool = True) -> None:
+        """
+        Sends local files to the remote directory and (optionally) deletes
+        unnecessary ones.
+
+        :param delete: Whether to delete remote files that are \
+        no longer present in local directory
+        :type delete: bool
+        """
         self._push_sync()
         if delete:
             self._delete()
